Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(57)

Unified Diff: chrome/browser/plugins/chrome_plugin_service_filter.h

Issue 2378573005: [HBD] Blanket BLOCK on all non-HTTP(s) and non-FILE URLs for Flash. (Closed)
Patch Set: fix dat merge Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/plugins/chrome_plugin_service_filter.h
diff --git a/chrome/browser/plugins/chrome_plugin_service_filter.h b/chrome/browser/plugins/chrome_plugin_service_filter.h
index 0dbc0ca9c4ceaecab70c698bd6ea68525da090f3..f8b651f1ddc49dc159741d1e5157457c5158d264 100644
--- a/chrome/browser/plugins/chrome_plugin_service_filter.h
+++ b/chrome/browser/plugins/chrome_plugin_service_filter.h
@@ -20,6 +20,7 @@
#include "content/public/browser/plugin_service_filter.h"
#include "content/public/common/webplugininfo.h"
#include "url/gurl.h"
+#include "url/origin.h"
class Profile;
@@ -64,13 +65,13 @@ class ChromePluginServiceFilter : public content::PluginServiceFilter,
const std::string& identifier);
// PluginServiceFilter implementation.
// If |plugin_content_url| is not available, the same GURL passed as
// |top_level_url| should be passed. These GURLs may be empty.
bool IsPluginAvailable(int render_process_id,
int render_frame_id,
const void* context,
const GURL& plugin_content_url,
- const GURL& top_level_url,
+ const url::Origin& main_frame_origin,
content::WebPluginInfo* plugin) override;
// CanLoadPlugin always grants permission to the browser
« no previous file with comments | « chrome/browser/download/download_target_determiner_unittest.cc ('k') | chrome/browser/plugins/chrome_plugin_service_filter.cc » ('j') | no next file with comments »
@@ -64,13 +65,13 @@ class ChromePluginServiceFilter : public content::PluginServiceFilter,
const std::string& identifier);
// PluginServiceFilter implementation.
- // If |plugin_content_url| is not available, the same GURL passed as
- // |top_level_url| should be passed. These GURLs may be empty.
+ // If |plugin_content_url| is not available, pass the same URL used to
+ // generate |main_frame_origin|. These parameters may be empty.
bool IsPluginAvailable(int render_process_id,
int render_frame_id,

Powered by Google App Engine
This is Rietveld 408576698